# slot_with_space_2

None

URI: https://w3id.org/linkml/tests/kitchen_sink/slot_with_space_2



<!-- no inheritance hierarchy -->


## Properties

 * Range: class with spaces

## Identifier and Mapping Information


